@@ -394,34 +394,6 @@ namespace symspellcpppy {
         return suggestions;
     }//end if
 
-    std::vector<xstring> SymSpell::LookupTerm(xstring input, Verbosity verbosity) {
-        auto results = Lookup(std::move(input), verbosity, this->maxDictionaryEditDistance, false);
-        std::vector<xstring> terms;
-        std::transform(results.begin(), results.end(), std::back_inserter(terms), [](const SuggestItem &item) {
-            return item.term;
-        });
-        return terms;
-    }
-
-    std::vector<xstring> SymSpell::LookupTerm(xstring input, Verbosity verbosity, int maxEditDistance) {
-        auto results = Lookup(std::move(input), verbosity, maxEditDistance, false);
-        std::vector<xstring> terms;
-        std::transform(results.begin(), results.end(), std::back_inserter(terms), [](const SuggestItem &item) {
-            return item.term;
-        });
-        return terms;
-    }
-
-    std::vector<xstring>
-    SymSpell::LookupTerm(xstring input, Verbosity verbosity, int maxEditDistance, bool includeUnknown) {
-        auto results = Lookup(std::move(input), verbosity, maxEditDistance, includeUnknown);
-        std::vector<xstring> terms;
-        std::transform(results.begin(), results.end(), std::back_inserter(terms), [](const SuggestItem &item) {
-            return item.term;
-        });
-        return terms;
-    }
-
     bool SymSpell::DeleteInSuggestionPrefix(xstring deleteSugg, int deleteLen, xstring suggestion,
                                             int suggestionLen) const {
         if (deleteLen == 0) return true;
@@ -567,24 +539,24 @@ namespace symspellcpppy {
                                     if (!suggestions.empty()) {
                                         if ((suggestions1[0].term + suggestions2[0].term == termList1[i])) {
                                             suggestionSplit.count = std::max(suggestionSplit.count,
-                                                                         suggestions[0].count + 2);
+                                                                             suggestions[0].count + 2);
                                         } else if ((suggestions1[0].term == suggestions[0].term) ||
                                                    (suggestions2[0].term == suggestions[0].term)) {
                                             suggestionSplit.count = std::max(suggestionSplit.count,
-                                                                         suggestions[0].count + 1);
+                                                                             suggestions[0].count + 1);
                                         }
                                     } else if ((suggestions1[0].term + suggestions2[0].term == termList1[i])) {
                                         suggestionSplit.count = std::max(suggestionSplit.count,
-                                                                     std::max(suggestions1[0].count,
-                                                                          suggestions2[0].count) +
-                                                                     2);
+                                                                         std::max(suggestions1[0].count,
+                                                                                  suggestions2[0].count) +
+                                                                         2);
                                     }
 
                                 } else {
                                     suggestionSplit.count = std::min(bigramCountMin,
-                                                                 (int64_t) ((double) suggestions1[0].count /
-                                                                            (double) N *
-                                                                            (double) suggestions2[0].count));
+                                                                     (int64_t) ((double) suggestions1[0].count /
+                                                                                (double) N *
+                                                                                (double) suggestions2[0].count));
                                 }
 
                                 if (suggestionSplit.count > suggestionSplitBest.count)
@@ -631,24 +603,6 @@ namespace symspellcpppy {
         return suggestionsLine;
     }
 
-    std::vector<xstring> SymSpell::LookupCompoundTerm(const xstring &input) {
-        auto results = LookupCompound(input, this->maxDictionaryEditDistance);
-        std::vector<xstring> terms;
-        std::transform(results.begin(), results.end(), std::back_inserter(terms), [](const SuggestItem &item) {
-            return item.term;
-        });
-        return terms;
-    }
-
-    std::vector<xstring> SymSpell::LookupCompoundTerm(const xstring &input, int editDistanceMax) {
-        auto results = LookupCompound(input, editDistanceMax);
-        std::vector<xstring> terms;
-        std::transform(results.begin(), results.end(), std::back_inserter(terms), [](const SuggestItem &item) {
-            return item.term;
-        });
-        return terms;
-    }
-
     Info SymSpell::WordSegmentation(const xstring &input) {
         return WordSegmentation(input, this->MaxDictionaryEditDistance(), this->maxDictionaryWordLength);
     }
